xpl: Rename spl_in_proper() to not_xpl()

Give this function a slightly easier name.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/spl.h b/include/spl.h
index bf01113..9484861 100644
--- a/include/spl.h
+++ b/include/spl.h
@@ -134,8 +134,8 @@
 #endif
 }
 
-/* returns true if in U-Boot proper, false if in SPL */
-static inline bool spl_in_proper(void)
+/* returns true if in U-Boot proper, false if in xPL */
+static inline bool not_xpl(void)
 {
 #ifdef CONFIG_SPL_BUILD
 	return false;